@@ -25,11 +25,12 @@ def join(token,link,print="true"):
      apilink = "https://discord.com/api/v9/invite/" + link
      headers={'Authorization': token}
      requests.post(apilink, headers=headers)
-     print(f"入れた～ {token}:{link}")
-    try:
+     try:
       raise Exception(f"エラーが発生しました…")
-    except Exception as e:
+     except Exception as e:
       print(e)
+     print(f"入れた～ {token}:{link}")
+    
       
 
 def leave(token,guild_id,print="true"):
@@ -41,7 +42,7 @@ def leave(token,guild_id,print="true"):
     headers={'Authorization': token}
     apilink = "https://discord.com/api/v9/users/@me/guilds/" + guild_id
     requests.delete(url, headers=headers)
-    print("抜けたよ～ {token}:{guild_id}")
+    print(f"抜けたよ～ {token}:{guild_id}")
   try:
     raise Exception(f"エラーが発生しました…")
   except Exception as e:
@@ -70,7 +71,6 @@ def report(token,guild_id,channel_id,message_id,reason):
     print(e)
 def ditoloprint(message):
   print(message)
-  try:
-    raise Exception(f"エラーが発生しました…")
+  raise Exception(f"エラーが発生しました…")
   except Exception as e:
     print(e)
\ No newline at end of file
